@@ -6,13 +6,16 @@ use Carp qw( croak );
 use base qw( FFI::Platypus::TypeParser );
 
 # ABSTRACT: FFI Type Parser Version One
-our $VERSION = '0.91_02'; # TRIAL VERSION
+our $VERSION = '0.93_02'; # TRIAL VERSION
 
 
 our @CARP_NOT = qw( FFI::Platypus FFI::Platypus::TypeParser );
 
 my %reserved = map { $_ => 1 } qw(
   struct
+  record
+  string
+  senum
   enum
 );
 
@@ -248,7 +251,7 @@ FFI::Platypus::TypeParser::Version1 - FFI Type Parser Version One
 
 =head1 VERSION
 
-version 0.91_02
+version 0.93_02
 
 =head1 SYNOPSIS
 
